xsdata.formats.dataclass.models.generics module
===============================================

.. automodule:: xsdata.formats.dataclass.models.generics
   :members:
   :undoc-members:
   :show-inheritance:
